fhirpack.transformation.observation — fhirpack 0.0.2b0 documentation

# Source code for fhirpack.transformation.observation

    import json
    import importlib
    from typing import Union

    import pandas as pd

    from fhirpy.lib import SyncFHIRResource
    from fhirpy.lib import SyncFHIRReference

    import fhirpack.transformation.base as base

    class TransformerObservationMixin(base.BaseTransformerMixin):
        def transformerObservationMethod(
            self,
        ):
            pass